@@ -63,6 +63,13 @@
 #' want to tweak this object with the goal to fix the orders between
 #' the levels of one given predictor. One easy way to do this is by
 #' tweaking an output returned from \code{dictionary()}.
+#' 
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#' `terms` (the selectors or variables selected), `value`, `n_tot`, `n_bad`,
+#' `n_good`, `p_bad`, `p_good`, `woe` and `outcome` is returned.. See 
+#' [dictionary()] for more information.
 #'
 #' @references Kullback, S. (1959). *Information Theory and Statistics.* Wiley, New York.
 #'
@@ -77,7 +84,7 @@
 #' set.seed(111)
 #' in_training <- sample(1:nrow(credit_data), 2000)
 #'
-#' credit_tr <- credit_data[ in_training, ]
+#' credit_tr <- credit_data[in_training, ]
 #' credit_te <- credit_data[-in_training, ]
 #'
 #' rec <- recipe(Status ~ ., data = credit_tr) %>%
@@ -88,23 +95,26 @@
 #' # the encoding:
 #' bake(woe_models, new_data = credit_te %>% slice(1:5), starts_with("woe"))
 #' # the original data
-#' credit_te %>% slice(1:5) %>% dplyr::select(Job, Home)
+#' credit_te %>%
+#'   slice(1:5) %>%
+#'   dplyr::select(Job, Home)
 #' # the details:
 #' tidy(woe_models, number = 1)
 #'
 #' # Example of custom dictionary + tweaking
 #' # custom dictionary
 #' woe_dict_custom <- credit_tr %>% dictionary(Job, Home, outcome = "Status")
-#' woe_dict_custom[4, "woe"] <- 1.23 #tweak
+#' woe_dict_custom[4, "woe"] <- 1.23 # tweak
 #'
-#' #passing custom dict to step_woe()
+#' # passing custom dict to step_woe()
 #' rec_custom <- recipe(Status ~ ., data = credit_tr) %>%
 #'   step_woe(Job, Home, outcome = vars(Status), dictionary = woe_dict_custom) %>%
-#'   prep
+#'   prep()
 #'
 #' rec_custom_baked <- bake(rec_custom, new_data = credit_te)
-#' rec_custom_baked %>% dplyr::filter(woe_Job == 1.23) %>% head
-#'
+#' rec_custom_baked %>%
+#'   dplyr::filter(woe_Job == 1.23) %>%
+#'   head()
 step_woe <- function(recipe,
                      ...,
                      role = "predictor",
@@ -118,7 +128,7 @@ step_woe <- function(recipe,
   if (missing(outcome)) {
     rlang::abort('argument "outcome" is missing, with no default')
   }
-  
+
   add_step(
     recipe,
     step_woe_new(
@@ -172,17 +182,23 @@ step_woe_new <- function(terms, role, trained, outcome, dictionary, Laplace, pre
 #'
 #' Good, I. J. (1985), "Weight of evidence: A brief survey", _Bayesian Statistics_, 2, pp.249-270.
 woe_table <- function(predictor, outcome, Laplace = 1e-6) {
-  outcome_original_labels <- unique(outcome)
-  
-  if (length(outcome_original_labels) != 2) {
-    rlang::abort(sprintf("'outcome' must have exactly 2 categories (has %s)",
-                 length(outcome_original_labels)))
+  if (is.factor(outcome)) {
+    outcome_original_labels <- levels(outcome)
+  } else {
+    outcome_original_labels <- unique(outcome)
   }
-  
+
+  if (length(outcome_original_labels) != 2) {
+    rlang::abort(sprintf(
+      "'outcome' must have exactly 2 categories (has %s)",
+      length(outcome_original_labels)
+    ))
+  }
+
   if (is.factor(predictor)) {
     predictor <- as.character(predictor)
   }
-  
+
   woe_expr <- parse(
     text = sprintf(
       "log(((n_%s + Laplace)/(sum(n_%s) + 2 * Laplace))/((n_%s + Laplace)/(sum(n_%s) + 2 * Laplace)))",
@@ -192,7 +208,7 @@ woe_table <- function(predictor, outcome, Laplace = 1e-6) {
       outcome_original_labels[2]
     )
   )
-  
+
   woe_tbl <-
     tibble::tibble(outcome, predictor) %>%
     dplyr::group_by(outcome, predictor) %>%
@@ -200,7 +216,7 @@ woe_table <- function(predictor, outcome, Laplace = 1e-6) {
     dplyr::group_by(predictor) %>%
     dplyr::mutate(n_tot = sum(n)) %>%
     dplyr::group_by(outcome) %>%
-    dplyr::mutate(p = n/sum(n)) %>%
+    dplyr::mutate(p = n / sum(n)) %>%
     tidyr::gather(summary, value, n, p) %>%
     tidyr::unite(summary_outcome, summary, outcome) %>%
     tidyr::spread(summary_outcome, value, fill = 0) %>%
@@ -208,7 +224,7 @@ woe_table <- function(predictor, outcome, Laplace = 1e-6) {
       woe = eval(woe_expr),
       predictor = as.character(predictor)
     )
-  
+
   return(woe_tbl)
 }
 
@@ -235,8 +251,6 @@ woe_table <- function(predictor, outcome, Laplace = 1e-6) {
 #' @examples
 #'
 #' mtcars %>% dictionary("am", cyl, gear:carb)
-#'
-#'
 #' @references Kullback, S. (1959). *Information Theory and Statistics.* Wiley, New York.
 #'
 #' Hastie, T., Tibshirani, R. and Friedman, J. (1986). *Elements of Statistical Learning*, Second Edition, Springer, 2009.
@@ -250,7 +264,7 @@ dictionary <- function(.data, outcome, ..., Laplace = 1e-6) {
   .data %>%
     dplyr::select(..., -!!outcome) %>%
     purrr::map(woe_table, outcome = outcome_vector, Laplace = Laplace) %>%
-    dplyr::bind_rows(.id = "variable") %>% 
+    dplyr::bind_rows(.id = "variable") %>%
     mutate(outcome = outcome)
 }
 
@@ -278,8 +292,6 @@ dictionary <- function(.data, outcome, ..., Laplace = 1e-6) {
 #' @examples
 #'
 #' mtcars %>% add_woe("am", cyl, gear:carb)
-#'
-
 #' @export
 add_woe <- function(.data, outcome, ..., dictionary = NULL, prefix = "woe") {
   if (missing(.data)) {
@@ -311,28 +323,29 @@ add_woe <- function(.data, outcome, ..., dictionary = NULL, prefix = "woe") {
   } else {
     dots_vars <- names(.data %>% dplyr::select(...))
   }
-  
+
   output <- dictionary %>%
     dplyr::filter(variable %in% dots_vars) %>%
     dplyr::select(variable, predictor, woe)
-  
+
   # See https://tidyr.tidyverse.org/dev/articles/in-packages.html
   if (tidyr_new_interface()) {
     output <- tidyr::nest(output, woe_table = -dplyr::one_of("variable"))
   } else {
     output <- tidyr::nest(output, .key = "woe_table")
   }
-  
-  output <- 
+
+  output <-
     output %>%
     dplyr::mutate(
       woe_table =
-        purrr::map2(woe_table, variable,
-                    ~ purrr::set_names(.x, c(.y, paste0(prefix,"_", .y)))
+        purrr::map2(
+          woe_table, variable,
+          ~ purrr::set_names(.x, c(.y, paste0(prefix, "_", .y)))
         ) %>%
-        purrr::set_names(variable)
+          purrr::set_names(variable)
     )
-  
+
   output <- purrr::map2(
     output$woe_table,
     output$variable, ~ {
@@ -341,10 +354,11 @@ add_woe <- function(.data, outcome, ..., dictionary = NULL, prefix = "woe") {
         dplyr::mutate_all(as.character) %>%
         dplyr::left_join(.x, by = .y) %>%
         dplyr::select(starts_with(prefix))
-    }) %>%
+    }
+  ) %>%
     dplyr::bind_cols(.data, .) %>%
     tibble::as_tibble()
-  
+
   output
 }
 
@@ -352,39 +366,40 @@ add_woe <- function(.data, outcome, ..., dictionary = NULL, prefix = "woe") {
 #' @export
 prep.step_woe <- function(x, training, info = NULL, ...) {
   col_names <- recipes::recipes_eval_select(x$terms, training, info)
-  
+
   if (length(col_names) > 0) {
     outcome_name <- recipes::recipes_eval_select(x$outcome, training, info)
-    
+
     col_names <- col_names[!(col_names %in% outcome_name)]
     check_type(training[, col_names], quant = FALSE)
     check_type(training[, outcome_name], quant = FALSE)
-    
+
     if (is.null(x$dictionary)) {
       x$dictionary <- dictionary(
         .data = training[, unique(c(outcome_name, col_names))],
         outcome = outcome_name
-      ) %>% 
+      ) %>%
         dplyr::mutate(outcome = outcome_name)
     }
-    
-    n_count <- 
-      x$dictionary %>% 
-      dplyr::group_by(variable) %>% 
+
+    n_count <-
+      x$dictionary %>%
+      dplyr::group_by(variable) %>%
       dplyr::summarize(low_n = sum(n_tot < 10))
-    
+
     if (any(n_count$low_n > 0)) {
       flagged <- n_count$variable[n_count$low_n > 0]
       flagged <- paste0("'", unique(flagged), "'", collapse = ", ")
-      msg <- paste0("Some columns used by `step_woe()` have categories with ",
-                    "less than 10 values: ", flagged)
+      msg <- glue(
+        "Some columns used by `step_woe()` have categories with ",
+        "less than 10 values: {flagged}"
+      )
       rlang::warn(msg)
     }
-    
   } else {
     x$dictionary <- tibble::tibble()
   }
-  
+
   step_woe_new(
     terms = x$terms,
     role = x$role,
@@ -417,30 +432,33 @@ bake.step_woe <- function(object, new_data, ...) {
 
 #' @export
 print.step_woe <- function(x, width = max(20, options()$width - 29), ...) {
-  cat("WoE version against outcome", rlang::quo_text(x$outcome[[1]]), "for ")
-  printer(unique(x$dictionary$variable), x$terms, x$trained, width = width)
+  outcome <- rlang::quo_text(x$outcome[[1]])
+  title <- paste("WoE version against outcome", outcome, "for ")
+  print_step(unique(x$dictionary$variable), x$terms, x$trained, title, width)
   invisible(x)
 }
 
 
-#' @rdname step_woe
+#' @rdname tidy.recipe
 #' @param x A `step_woe` object.
 #' @export
 tidy.step_woe <- function(x, ...) {
   if (is_trained(x)) {
-    res <- 
-      x$dictionary %>% 
+    res <-
+      x$dictionary %>%
       dplyr::rename(terms = variable, value = predictor)
   } else {
     term_names <- sel2char(x$terms)
-    res <- tibble(terms = term_names,
-                  value = rlang::na_chr,
-                  ntot = rlang::na_int,
-                  n_0 = rlang::na_int,
-                  n_1 = rlang::na_int,
-                  p_0 = rlang::na_dbl,
-                  p_1 = rlang::na_dbl,
-                  woe = rlang::na_dbl)
+    res <- tibble(
+      terms = term_names,
+      value = rlang::na_chr,
+      n_tot = rlang::na_int,
+      n_bad = rlang::na_int,
+      n_good = rlang::na_int,
+      p_bad = rlang::na_dbl,
+      p_good = rlang::na_dbl,
+      woe = rlang::na_dbl
+    )
   }
   res$id <- x$id
   res
@@ -460,4 +478,3 @@ tidyr_new_interface <- function() {
 required_pkgs.step_woe <- function(x, ...) {
   c("embed")
 }
-
