@@ -10,55 +10,55 @@ test_that("factor encoded predictor", {
     prep(training = ex_dat, retain = TRUE)
   tr_values <- juice(class_test)$x3
   new_values <- bake(class_test, new_data = new_dat)
-  expect_warning(
+  expect_snapshot(
     new_values_ch <- bake(class_test, new_data = new_dat_ch)
   )
   key <- class_test$steps[[1]]$mapping
   td_obj <- tidy(class_test, number = 1)
-  
+
   expect_equal("x3", names(key))
-  
+
   expect_equal(
     length(unique(ex_dat$x3)) + 1,
     nrow(key$x3)
   )
   expect_true(sum(key$x3$..level == "..new") == 1)
-  
+
   expect_true(is.numeric(tr_values))
-  
+
   expect_equal(
-    new_values$x3[1], 
+    new_values$x3[1],
     key$x3$..value[key$x3$..level == "..new"]
   )
   expect_equal(
-    new_values$x3[2], 
-    key$x3$..value[ key$x3$..level == levels(ex_dat$x3)[1] ]
+    new_values$x3[2],
+    key$x3$..value[key$x3$..level == levels(ex_dat$x3)[1]]
   )
   expect_equal(
-    new_values$x3[3], 
+    new_values$x3[3],
     key$x3$..value[key$x3$..level == "..new"]
   )
   expect_equal(
-    new_values_ch$x3[1], 
+    new_values_ch$x3[1],
     key$x3$..value[key$x3$..level == "..new"]
   )
   expect_equal(
-    new_values_ch$x3[2], 
-    key$x3$..value[ key$x3$..level == levels(ex_dat$x3)[1] ]
-  )  
+    new_values_ch$x3[2],
+    key$x3$..value[key$x3$..level == levels(ex_dat$x3)[1]]
+  )
   expect_equal(
-    new_values_ch$x3[3], 
+    new_values_ch$x3[3],
     key$x3$..value[key$x3$..level == "..new"]
-  )  
-  
+  )
+
   expect_equal(
-    td_obj$level, 
+    td_obj$level,
     key$x3$..level
-  )  
+  )
   expect_equal(
-    td_obj$value, 
+    td_obj$value,
     key$x3$..value
-  )   
+  )
 })
 
 test_that("character encoded predictor", {
@@ -68,53 +68,53 @@ test_that("character encoded predictor", {
     prep(training = ex_dat_ch, retain = TRUE)
   tr_values <- juice(class_test)$x3
   new_values <- bake(class_test, new_data = new_dat_ch)
-  new_values_fc <- bake(class_test, new_data = new_dat)  
+  new_values_fc <- bake(class_test, new_data = new_dat)
   key <- class_test$steps[[1]]$mapping
   td_obj <- tidy(class_test, number = 1)
-  
+
   expect_equal("x3", names(key))
-  
+
   expect_equal(
     length(unique(ex_dat$x3)) + 1,
     nrow(key$x3)
   )
   expect_true(sum(key$x3$..level == "..new") == 1)
-  
+
   expect_true(is.numeric(tr_values))
-  
+
   expect_equal(
-    new_values$x3[1], 
+    new_values$x3[1],
     key$x3$..value[key$x3$..level == "..new"]
   )
   expect_equal(
-    new_values$x3[2], 
-    key$x3$..value[ key$x3$..level == levels(ex_dat$x3)[1] ]
+    new_values$x3[2],
+    key$x3$..value[key$x3$..level == levels(ex_dat$x3)[1]]
   )
   expect_equal(
-    new_values$x3[3], 
-    key$x3$..value[key$x3$..level == "..new"]
-  )  
-  expect_equal(
-    new_values_fc$x3[1], 
+    new_values$x3[3],
     key$x3$..value[key$x3$..level == "..new"]
   )
   expect_equal(
-    new_values_fc$x3[2], 
-    key$x3$..value[ key$x3$..level == levels(ex_dat$x3)[1] ]
-  )  
-  expect_equal(
-    new_values_fc$x3[3], 
+    new_values_fc$x3[1],
     key$x3$..value[key$x3$..level == "..new"]
-  )  
-  
+  )
   expect_equal(
-    td_obj$level, 
+    new_values_fc$x3[2],
+    key$x3$..value[key$x3$..level == levels(ex_dat$x3)[1]]
+  )
+  expect_equal(
+    new_values_fc$x3[3],
+    key$x3$..value[key$x3$..level == "..new"]
+  )
+
+  expect_equal(
+    td_obj$level,
     key$x3$..level
-  )  
+  )
   expect_equal(
-    td_obj$value, 
+    td_obj$value,
     key$x3$..value
-  )     
+  )
 })
 
 ###################################################################
@@ -126,56 +126,56 @@ test_that("factor encoded predictor", {
     prep(training = ex_dat, retain = TRUE)
   tr_values <- juice(reg_test)$x3
   new_values <- bake(reg_test, new_data = new_dat)
-  expect_warning(
+  expect_snapshot(
     new_values_ch <- bake(reg_test, new_data = new_dat_ch)
   )
   td_obj <- tidy(reg_test, number = 1)
-  
+
   key <- reg_test$steps[[1]]$mapping
-  
+
   expect_equal("x3", names(key))
-  
+
   expect_equal(
     length(unique(ex_dat$x3)) + 1,
     nrow(key$x3)
   )
   expect_true(sum(key$x3$..level == "..new") == 1)
-  
+
   expect_true(is.numeric(tr_values))
-  
+
   expect_equal(
-    new_values$x3[1], 
+    new_values$x3[1],
     key$x3$..value[key$x3$..level == "..new"]
   )
   expect_equal(
-    new_values$x3[2], 
-    key$x3$..value[ key$x3$..level == levels(ex_dat$x3)[1] ]
+    new_values$x3[2],
+    key$x3$..value[key$x3$..level == levels(ex_dat$x3)[1]]
   )
   expect_equal(
-    new_values$x3[3], 
+    new_values$x3[3],
     key$x3$..value[key$x3$..level == "..new"]
   )
   expect_equal(
-    new_values_ch$x3[1], 
+    new_values_ch$x3[1],
     key$x3$..value[key$x3$..level == "..new"]
   )
   expect_equal(
-    new_values_ch$x3[2], 
-    key$x3$..value[ key$x3$..level == levels(ex_dat$x3)[1] ]
-  )  
+    new_values_ch$x3[2],
+    key$x3$..value[key$x3$..level == levels(ex_dat$x3)[1]]
+  )
   expect_equal(
-    new_values_ch$x3[3], 
+    new_values_ch$x3[3],
     key$x3$..value[key$x3$..level == "..new"]
-  )  
-  
+  )
+
   expect_equal(
-    td_obj$level, 
+    td_obj$level,
     key$x3$..level
-  )  
+  )
   expect_equal(
-    td_obj$value, 
+    td_obj$value,
     key$x3$..value
-  )      
+  )
 })
 
 test_that("character encoded predictor", {
@@ -185,53 +185,53 @@ test_that("character encoded predictor", {
     prep(training = ex_dat_ch, retain = TRUE)
   tr_values <- juice(reg_test)$x3
   new_values <- bake(reg_test, new_data = new_dat_ch)
-  new_values_fc <- bake(reg_test, new_data = new_dat)  
+  new_values_fc <- bake(reg_test, new_data = new_dat)
   key <- reg_test$steps[[1]]$mapping
   td_obj <- tidy(reg_test, number = 1)
-  
+
   expect_equal("x3", names(key))
-  
+
   expect_equal(
     length(unique(ex_dat$x3)) + 1,
     nrow(key$x3)
   )
   expect_true(sum(key$x3$..level == "..new") == 1)
-  
+
   expect_true(is.numeric(tr_values))
-  
+
   expect_equal(
-    new_values$x3[1], 
+    new_values$x3[1],
     key$x3$..value[key$x3$..level == "..new"]
   )
   expect_equal(
-    new_values$x3[2], 
-    key$x3$..value[ key$x3$..level == levels(ex_dat$x3)[1] ]
+    new_values$x3[2],
+    key$x3$..value[key$x3$..level == levels(ex_dat$x3)[1]]
   )
   expect_equal(
-    new_values$x3[3], 
-    key$x3$..value[key$x3$..level == "..new"]
-  )  
-  expect_equal(
-    new_values_fc$x3[1], 
+    new_values$x3[3],
     key$x3$..value[key$x3$..level == "..new"]
   )
   expect_equal(
-    new_values_fc$x3[2], 
-    key$x3$..value[ key$x3$..level == levels(ex_dat$x3)[1] ]
-  )  
-  expect_equal(
-    new_values_fc$x3[3], 
+    new_values_fc$x3[1],
     key$x3$..value[key$x3$..level == "..new"]
-  )  
-  
+  )
   expect_equal(
-    td_obj$level, 
+    new_values_fc$x3[2],
+    key$x3$..value[key$x3$..level == levels(ex_dat$x3)[1]]
+  )
+  expect_equal(
+    new_values_fc$x3[3],
+    key$x3$..value[key$x3$..level == "..new"]
+  )
+
+  expect_equal(
+    td_obj$level,
     key$x3$..level
-  )  
+  )
   expect_equal(
-    td_obj$value, 
+    td_obj$value,
     key$x3$..value
-  )    
+  )
 })
 
 
@@ -242,8 +242,8 @@ test_that("bad args", {
   three_class <- iris
   three_class$fac <- rep(letters[1:3], 50)
   three_class$logical <- rep(c(TRUE, FALSE), 75)
-  
-  expect_error(
+
+  expect_snapshot(error = TRUE,
     recipe(Species ~ ., data = three_class) %>%
       step_lencode_mixed(Sepal.Length, outcome = vars(Species)) %>%
       prep(training = three_class, retain = TRUE)
@@ -251,11 +251,11 @@ test_that("bad args", {
 })
 
 
-test_that('printing', {
+test_that("printing", {
   skip_if_not_installed("lme4")
   print_test <- recipe(x2 ~ ., data = ex_dat_ch) %>%
-    step_lencode_mixed(x3, outcome = vars(x2)) 
-  expect_snapshot(print(print_test))
+    step_lencode_mixed(x3, outcome = vars(x2))
+  expect_snapshot(print_test)
   expect_snapshot(prep(print_test, training = ex_dat_ch, verbose = TRUE))
 })
 
@@ -266,7 +266,7 @@ test_that("empty selections", {
   expect_error(
     rec <-
       recipe(Class ~ Genotype + tau, data = ad_data) %>%
-      step_lencode_mixed(starts_with("potato"), outcome = vars(Class)) %>% 
+      step_lencode_mixed(starts_with("potato"), outcome = vars(Class)) %>%
       prep(),
     regexp = NA
   )
@@ -274,4 +274,4 @@ test_that("empty selections", {
     bake(rec, new_data = NULL),
     ad_data %>% select(Genotype, tau, Class)
   )
-})
\ No newline at end of file
+})
