@@ -10,55 +10,55 @@ test_that("factor encoded predictor", {
     prep(training = ex_dat, retain = TRUE)
   tr_values <- juice(class_test)$x3
   new_values <- bake(class_test, new_data = new_dat)
-  expect_warning(
+  expect_snapshot(
     new_values_ch <- bake(class_test, new_data = new_dat_ch)
   )
   key <- class_test$steps[[1]]$mapping
   td_obj <- tidy(class_test, number = 1)
-  
+
   expect_equal("x3", names(key))
-  
+
   expect_equal(
     length(unique(ex_dat$x3)) + 1,
     nrow(key$x3)
   )
   expect_true(sum(key$x3$..level == "..new") == 1)
-  
+
   expect_true(is.numeric(tr_values))
-  
+
   expect_equal(
-    new_values$x3[1], 
+    new_values$x3[1],
     key$x3$..value[key$x3$..level == "..new"]
   )
   expect_equal(
-    new_values$x3[2], 
-    key$x3$..value[ key$x3$..level == levels(ex_dat$x3)[1] ]
+    new_values$x3[2],
+    key$x3$..value[key$x3$..level == levels(ex_dat$x3)[1]]
   )
   expect_equal(
-    new_values$x3[3], 
+    new_values$x3[3],
     key$x3$..value[key$x3$..level == "..new"]
   )
   expect_equal(
-    new_values_ch$x3[1], 
+    new_values_ch$x3[1],
     key$x3$..value[key$x3$..level == "..new"]
   )
   expect_equal(
-    new_values_ch$x3[2], 
-    key$x3$..value[ key$x3$..level == levels(ex_dat$x3)[1] ]
-  )  
+    new_values_ch$x3[2],
+    key$x3$..value[key$x3$..level == levels(ex_dat$x3)[1]]
+  )
   expect_equal(
-    new_values_ch$x3[3], 
+    new_values_ch$x3[3],
     key$x3$..value[key$x3$..level == "..new"]
-  )  
-  
+  )
+
   expect_equal(
-    td_obj$level, 
+    td_obj$level,
     key$x3$..level
-  )  
+  )
   expect_equal(
-    td_obj$value, 
+    td_obj$value,
     key$x3$..value
-  )   
+  )
 })
 
 test_that("character encoded predictor", {
@@ -66,116 +66,117 @@ test_that("character encoded predictor", {
     step_lencode_glm(x3, outcome = vars(x2)) %>%
     prep(training = ex_dat_ch, retain = TRUE)
   tr_values <- juice(class_test)$x3
-  new_values <- bake(class_test, new_data = new_dat_ch)
-  new_values_fc <- bake(class_test, new_data = new_dat)  
+  expect_snapshot(
+    new_values <- bake(class_test, new_data = new_dat_ch)
+  )
+  new_values_fc <- bake(class_test, new_data = new_dat)
   key <- class_test$steps[[1]]$mapping
   td_obj <- tidy(class_test, number = 1)
-  
+
   expect_equal("x3", names(key))
-  
+
   expect_equal(
     length(unique(ex_dat$x3)) + 1,
     nrow(key$x3)
   )
   expect_true(sum(key$x3$..level == "..new") == 1)
-  
+
   expect_true(is.numeric(tr_values))
-  
+
   expect_equal(
-    new_values$x3[1], 
+    new_values$x3[1],
     key$x3$..value[key$x3$..level == "..new"]
   )
   expect_equal(
-    new_values$x3[2], 
-    key$x3$..value[ key$x3$..level == levels(ex_dat$x3)[1] ]
+    new_values$x3[2],
+    key$x3$..value[key$x3$..level == levels(ex_dat$x3)[1]]
   )
   expect_equal(
-    new_values$x3[3], 
-    key$x3$..value[key$x3$..level == "..new"]
-  )  
-  expect_equal(
-    new_values_fc$x3[1], 
+    new_values$x3[3],
     key$x3$..value[key$x3$..level == "..new"]
   )
   expect_equal(
-    new_values_fc$x3[2], 
-    key$x3$..value[ key$x3$..level == levels(ex_dat$x3)[1] ]
-  )  
-  expect_equal(
-    new_values_fc$x3[3], 
+    new_values_fc$x3[1],
     key$x3$..value[key$x3$..level == "..new"]
-  )  
-  
+  )
   expect_equal(
-    td_obj$level, 
+    new_values_fc$x3[2],
+    key$x3$..value[key$x3$..level == levels(ex_dat$x3)[1]]
+  )
+  expect_equal(
+    new_values_fc$x3[3],
+    key$x3$..value[key$x3$..level == "..new"]
+  )
+
+  expect_equal(
+    td_obj$level,
     key$x3$..level
-  )  
+  )
   expect_equal(
-    td_obj$value, 
+    td_obj$value,
     key$x3$..value
-  )     
+  )
 })
 
 # ------------------------------------------------------------------------------
 
 test_that("factor encoded predictor", {
-  skip_on_os("mac")
-  
+
   reg_test <- recipe(x1 ~ ., data = ex_dat) %>%
     step_lencode_glm(x3, outcome = vars(x1)) %>%
     prep(training = ex_dat, retain = TRUE)
   tr_values <- juice(reg_test)$x3
   new_values <- bake(reg_test, new_data = new_dat)
-  expect_warning(
+  expect_snapshot(
     new_values_ch <- bake(reg_test, new_data = new_dat_ch)
   )
   td_obj <- tidy(reg_test, number = 1)
-  
+
   key <- reg_test$steps[[1]]$mapping
-  
+
   expect_equal("x3", names(key))
-  
+
   expect_equal(
     length(unique(ex_dat$x3)) + 1,
     nrow(key$x3)
   )
   expect_true(sum(key$x3$..level == "..new") == 1)
-  
+
   expect_true(is.numeric(tr_values))
-  
+
   expect_equal(
-    new_values$x3[1], 
+    new_values$x3[1],
     key$x3$..value[key$x3$..level == "..new"]
   )
   expect_equal(
-    new_values$x3[2], 
-    key$x3$..value[ key$x3$..level == levels(ex_dat$x3)[1] ]
+    new_values$x3[2],
+    key$x3$..value[key$x3$..level == levels(ex_dat$x3)[1]]
   )
   expect_equal(
-    new_values$x3[3], 
+    new_values$x3[3],
     key$x3$..value[key$x3$..level == "..new"]
   )
   expect_equal(
-    new_values_ch$x3[1], 
+    new_values_ch$x3[1],
     key$x3$..value[key$x3$..level == "..new"]
   )
   expect_equal(
-    new_values_ch$x3[2], 
-    key$x3$..value[ key$x3$..level == levels(ex_dat$x3)[1] ]
-  )  
+    new_values_ch$x3[2],
+    key$x3$..value[key$x3$..level == levels(ex_dat$x3)[1]]
+  )
   expect_equal(
-    new_values_ch$x3[3], 
+    new_values_ch$x3[3],
     key$x3$..value[key$x3$..level == "..new"]
-  )  
-  
+  )
+
   expect_equal(
-    td_obj$level, 
+    td_obj$level,
     key$x3$..level
-  )  
+  )
   expect_equal(
-    td_obj$value, 
+    td_obj$value,
     key$x3$..value
-  )      
+  )
 })
 
 test_that("character encoded predictor", {
@@ -184,53 +185,53 @@ test_that("character encoded predictor", {
     prep(training = ex_dat_ch, retain = TRUE)
   tr_values <- juice(reg_test)$x3
   new_values <- bake(reg_test, new_data = new_dat_ch)
-  new_values_fc <- bake(reg_test, new_data = new_dat)  
+  new_values_fc <- bake(reg_test, new_data = new_dat)
   key <- reg_test$steps[[1]]$mapping
   td_obj <- tidy(reg_test, number = 1)
-  
+
   expect_equal("x3", names(key))
-  
+
   expect_equal(
     length(unique(ex_dat$x3)) + 1,
     nrow(key$x3)
   )
   expect_true(sum(key$x3$..level == "..new") == 1)
-  
+
   expect_true(is.numeric(tr_values))
-  
+
   expect_equal(
-    new_values$x3[1], 
+    new_values$x3[1],
     key$x3$..value[key$x3$..level == "..new"]
   )
   expect_equal(
-    new_values$x3[2], 
-    key$x3$..value[ key$x3$..level == levels(ex_dat$x3)[1] ]
+    new_values$x3[2],
+    key$x3$..value[key$x3$..level == levels(ex_dat$x3)[1]]
   )
   expect_equal(
-    new_values$x3[3], 
-    key$x3$..value[key$x3$..level == "..new"]
-  )  
-  expect_equal(
-    new_values_fc$x3[1], 
+    new_values$x3[3],
     key$x3$..value[key$x3$..level == "..new"]
   )
   expect_equal(
-    new_values_fc$x3[2], 
-    key$x3$..value[ key$x3$..level == levels(ex_dat$x3)[1] ]
-  )  
-  expect_equal(
-    new_values_fc$x3[3], 
+    new_values_fc$x3[1],
     key$x3$..value[key$x3$..level == "..new"]
-  )  
-  
+  )
   expect_equal(
-    td_obj$level, 
+    new_values_fc$x3[2],
+    key$x3$..value[key$x3$..level == levels(ex_dat$x3)[1]]
+  )
+  expect_equal(
+    new_values_fc$x3[3],
+    key$x3$..value[key$x3$..level == "..new"]
+  )
+
+  expect_equal(
+    td_obj$level,
     key$x3$..level
-  )  
+  )
   expect_equal(
-    td_obj$value, 
+    td_obj$value,
     key$x3$..value
-  )    
+  )
 })
 
 
@@ -240,8 +241,8 @@ test_that("bad args", {
   three_class <- iris
   three_class$fac <- rep(letters[1:3], 50)
   three_class$logical <- rep(c(TRUE, FALSE), 75)
-  
-  expect_error(
+
+  expect_snapshot(error = TRUE,
     recipe(Species ~ ., data = three_class) %>%
       step_lencode_glm(Sepal.Length, outcome = vars(Species)) %>%
       prep(training = three_class, retain = TRUE)
@@ -249,10 +250,10 @@ test_that("bad args", {
 })
 
 
-test_that('printing', {
+test_that("printing", {
   print_test <- recipe(x2 ~ ., data = ex_dat_ch) %>%
-    step_lencode_glm(x3, outcome = vars(x2)) 
-  expect_snapshot(print(print_test))
+    step_lencode_glm(x3, outcome = vars(x2))
+  expect_snapshot(print_test)
   expect_snapshot(prep(print_test, training = ex_dat_ch, verbose = TRUE))
 })
 
@@ -264,7 +265,7 @@ test_that("empty selections", {
   expect_error(
     rec <-
       recipe(Class ~ Genotype + tau, data = ad_data) %>%
-      step_lencode_glm(starts_with("potato"), outcome = vars(Class)) %>% 
+      step_lencode_glm(starts_with("potato"), outcome = vars(Class)) %>%
       prep(),
     regexp = NA
   )
